@@ -297,7 +297,15 @@ device_resolve_type_and_icon (Device1 *device, BluetoothType *type, const char *
 	g_return_if_fail (type);
 	g_return_if_fail (icon);
 
-	*type = bluetooth_appearance_to_type (device1_get_appearance (device));
+	if (g_strcmp0 (device1_get_name (device), "ION iCade Game Controller") == 0 ||
+	    g_strcmp0 (device1_get_name (device), "8Bitdo Zero GamePad") == 0) {
+		*type = BLUETOOTH_TYPE_JOYPAD;
+		*icon = "input-gaming";
+		return;
+	}
+
+	if (*type == 0 || *type == BLUETOOTH_TYPE_ANY)
+		*type = bluetooth_appearance_to_type (device1_get_appearance (device));
 	if (*type == 0 || *type == BLUETOOTH_TYPE_ANY)
 		*type = bluetooth_class_to_type (device1_get_class (device));
 
@@ -389,7 +397,7 @@ device_added (GDBusObjectManager   *manager,
 	char **uuids;
 	gboolean paired, trusted, connected;
 	int legacypairing;
-	BluetoothType type;
+	BluetoothType type = BLUETOOTH_TYPE_ANY;
 	GtkTreeIter iter, parent;
 
 	g_signal_connect_object (G_OBJECT (device), "notify",
